import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.*;



/** 
 * Class DisplayFrame implements a frame which contains buttons that allow the
 * table used for this Sample Code application to be previewed and printed.
 *
 * <P>There is no JPDF-specific code in this class.  It is just a simple Swing
 * JFrame.
 */
public class DisplayFrame
  extends JFrame
{
  //-----------------------------------------------------------------------
  // Inner Classes.
  //-----------------------------------------------------------------------

  /**
   * Window Close Listener.  The Application is terminated when this frame is 
   * closed.
   */
  private static class WindowCloseListener 
    extends WindowAdapter
  {
    public void windowClosing(WindowEvent theEvent)
    {
      PreviewTableApplication.exitApplication(); 
    }
  }

  /**
   * The Print Preview button displays the table in a preview window.
   */
  private class PrintPreviewButton
    extends JButton
    implements ActionListener
  {
    private PrintPreviewButton() 
    {
      super("Preview");
      
      addActionListener(this);
    }

    public void actionPerformed(ActionEvent theEvent) 
    {
      setWaitCursor();
      PreviewTableApplication.displayPreviewWindow(DisplayFrame.this);
      setDefaultCursor();
    }
  }

  /**
   * The Print Button displays a Print Dialog that allows the table to be printed.
   */
  private class PrintButton
    extends JButton
    implements ActionListener
  {
    private PrintButton() 
    {
      super("Print");
      
      addActionListener(this);
    }

    public void actionPerformed(ActionEvent theEvent) 
    {
      setWaitCursor();
      PreviewTableApplication.displayPrintDialog(DisplayFrame.this);
      setDefaultCursor();
    }
  }

  
  //-----------------------------------------------------------------------
  // Constructors.
  //-----------------------------------------------------------------------
  
  public DisplayFrame() 
  {
    super("Preview and Print an off-screen Table");

    // Initialize the frame contents.
    initializeContents();
  }

    
  //-----------------------------------------------------------------------
  // Public methods.
  //-----------------------------------------------------------------------

  /**
   * Sets the cursor to the default cursor.
   */  
  public void setDefaultCursor()
  {
    setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
    getGlassPane().setVisible(false);
  }

  /**
   * Sets the cursor to the wait cursor.
   */  
  public void setWaitCursor()
  {
    getGlassPane().setVisible(true);
    setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
  }

   
  //-----------------------------------------------------------------------
  // Private methods.
  //-----------------------------------------------------------------------

  /**
   * Creates the Bottom Panel.
   */
  private JPanel createBottomPanel()
  {
    JPanel theBottomPanel = new JPanel(new BorderLayout());
    JLabel theAlertLabel = new JLabel();
    String theAlert = null;
    
    // Set the Alert Label text.
    theAlert = "<HTML><CENTER><FONT color='red'>" +
               "ALERT: The table used in this example requires approximately 20 pages to print. " +
               "You may want to print just a subset of these pages for testing purposes." +
               "</FONT></CENTER></HTML>";
    theAlertLabel.setText(theAlert);
    
    // Add the panel contents.
    theBottomPanel.add(theAlertLabel, BorderLayout.NORTH);
    theBottomPanel.add(createButtonPanel(), BorderLayout.CENTER);
    
    return theBottomPanel;
  }

  /**
   * Creates the Button Panel.
   */
  private JPanel createButtonPanel()
  {
    JPanel theButtonPanel = new JPanel();
    
    theButtonPanel.add(new PrintPreviewButton());
    theButtonPanel.add(new PrintButton());
    
    return theButtonPanel;
  }

  /**
   * Creates the Text Area.
   */
  private JTextArea createTextArea()
  {
    JTextArea theTextArea = new JTextArea();
    String    theText = null;
    
    // Configure the Text Area.
    theTextArea.setEditable(false);
    theTextArea.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
    theTextArea.setOpaque(false);
    theTextArea.setForeground(new Color(0,0, 128));
    theTextArea.setWrapStyleWord(true);
    theTextArea.setLineWrap(true);
    
    // Set the text.
    theText = "This JPDF Sample Code application allows you to preview and print a Swing Table (JTable).  " +
              "The table is not displayed on the screen to demonstrate the ability to preview and print " +
              "off-screen tables.\n\n" +
              "The Preview Button displays the table in a JPDF Preview Dialog.  From this Preview Dialog " +
              "you can display a JPDF Page Setup dialog to specify various options, and a JPDF Print Dialog " +
              "to print the table.\n\n" +
              "The Print Button displays a JPDF Print Dialog which allows you to print the table.";
    theTextArea.setText(theText);
    
    return theTextArea;
  }

  /**
   * Initializes the contents of this frame.
   */
  private void initializeContents()
  {
    Container theContentPane = getContentPane();
    
    // Configure the frame.
    setSize(550, 400);
    setLocationRelativeTo(null);

    // Add the contents.
    theContentPane.add(new JScrollPane(createTextArea()), BorderLayout.CENTER);
    theContentPane.add(createBottomPanel(), BorderLayout.SOUTH);
    
    // Add listeners.
    addWindowListener(new WindowCloseListener());
  }
}